#[non_exhaustive]pub enum Action {
Show 50 variants
FileOpen,
FileSave,
FileNew,
FolderNew,
FileRename,
FileDelete,
WorkspaceSearch,
WorkspaceRestoreDrafts,
PaneSplitRight,
FocusProject,
FocusEditor,
FocusAgent,
TerminalNew,
TerminalRun,
TerminalFocus,
TerminalNext,
TerminalPrevious,
TerminalRestart,
TerminalClose,
TerminalCopyMode,
GitShow,
GitStage,
GitUnstage,
GitCommit,
GitBranchCheckout,
GitFetch,
GitPull,
GitPush,
TaskRun,
TaskCancel,
ProblemsShow,
ProblemsNext,
ProblemsPrevious,
EditorGotoDefinition,
LspHover,
LspCompletion,
LspReferences,
LspDocumentSymbols,
LspWorkspaceSymbols,
LspRename,
LspCodeAction,
LspFormat,
LspRestart,
EditorApplyTransaction,
AgentSessionNew,
AgentPrompt,
AgentProposalAccept,
AgentProposalReject,
HelpShow,
ConfigReload,
}Expand description
A named, invocable action — the shared vocabulary of the keymap, command palette, plugins, and the agent tool schema exposed over ACP (3, 6.2).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FileOpen
FileSave
FileNew
FolderNew
FileRename
FileDelete
WorkspaceSearch
WorkspaceRestoreDrafts
PaneSplitRight
FocusProject
FocusEditor
FocusAgent
TerminalNew
TerminalRun
TerminalFocus
TerminalNext
TerminalPrevious
TerminalRestart
TerminalClose
TerminalCopyMode
GitShow
GitStage
GitUnstage
GitCommit
GitBranchCheckout
GitFetch
GitPull
GitPush
TaskRun
TaskCancel
ProblemsShow
ProblemsNext
ProblemsPrevious
EditorGotoDefinition
LspHover
LspCompletion
LspReferences
LspDocumentSymbols
LspWorkspaceSymbols
LspRename
LspCodeAction
LspFormat
LspRestart
EditorApplyTransaction
AgentSessionNew
AgentPrompt
AgentProposalAccept
AgentProposalReject
HelpShow
ConfigReload
Implementations
Sourceimpl Action
impl Action
Sourcepub fn id(&self) -> &'static str
pub fn id(&self) -> &'static str
The stable string id (also the tool name advertised to ACP agents).
Sourcepub fn title(&self) -> &'static str
pub fn title(&self) -> &'static str
Human-friendly label shown in menus and the command palette.
Sourcepub fn agent_needs_permission(&self) -> bool
pub fn agent_needs_permission(&self) -> bool
Whether an agent must ask permission before this runs (write/run/commit). 9.4